import 'package:knt_bloc/knt_bloc.dart';

import '../repository/monetized_repo.dart';
import '../service/iap_service.dart';

/// Handles free usage premium-feature flow.
class FreeUsageCounterBloc extends BaseBloc {
  final IapService _iapService;
  final MonetizedRepo _monetizedRepo;

  FreeUsageCounterBloc(this._iapService, this._monetizedRepo);

  Stream<BaseState> handleEvent(BaseEvent event) async* {
    yield* super.handleEvent(event);
    switch (event.runtimeType) {
      case ShowFreeUsageEvent:
        yield* _handleShowFreeUsageEvent(event as ShowFreeUsageEvent);
        break;
    }
  }

  /// Checks purchased status then shows free usage times
  Stream<BaseState> _handleShowFreeUsageEvent(ShowFreeUsageEvent event) async* {
    final purchased = await _monetizedRepo.fetchPurchasedIapStatus();
    final tag = event.tag;
    if (purchased) {
      yield ShownFreeUsageState(0, 99999, needShow: false, tag: tag);
      return;
    }
    final freeUsageCounted = await _monetizedRepo.fetchFreeUsedToday();
    yield ShownFreeUsageState(
      freeUsageCounted,
      _iapService.limitFreeIdentify,
      tag: tag,
    );
  }
}

// region EVENT
class ShowFreeUsageEvent extends BaseEvent {
  const ShowFreeUsageEvent({String? tag}) : super(tag: tag);
}
// endregion

// region STATE
class ShownFreeUsageState extends BaseState {
  final int _current;
  final int _total;
  final bool needShow;

  const ShownFreeUsageState(
    this._current,
    this._total, {
    this.needShow = true,
    String? tag,
  }) : super(tag: tag);

  int get hasLeft => _total - _current;

  String get presented => '$hasLeft/$_total';
}
// endregion
