import 'package:purchases_flutter/purchases_flutter.dart';

import '../model/models.dart';

class RevCatIapService {
  final RevcatIapConfig _config;

  const RevCatIapService(this._config);

  /// Initialize [Purchases] lib of RevenueCat, must be called before [runApp].
  ///
  /// For example:
  /// ```dart
  /// Future<void> main() async {
  ///   WidgetsFlutterBinding.ensureInitialized();
  ///   await getIt<RevCatIapService>().init();
  ///   runApp(App());
  /// }
  /// ```
  Future<void> init() async {
    await Purchases.setDebugLogsEnabled(enabledLogs);
    await Purchases.setup(publicKey, appUserId: appUserId);
  }

  String get publicKey => _config.publicKey;

  String get entitlementID => _config.entitlementID;

  String? get appUserId => _config.appUserId;

  bool get enabledLogs => _config.enabledLogs;

  int get limitFreeIdentify => _config.limitFreeUsage;

  List<SubscriptionItem> Function(List<Package>) get packageConverter =>
      _config.packageConverter;
}
